@@ -2,8 +2,6 @@
 
 #include "test-utils.h"
 
-#ifdef HAVE_APACHE
-
 SoupBuffer *full_response;
 int total_length;
 char *test_response;
@@ -78,7 +76,7 @@ check_part (SoupMessageHeaders *headers, const char *body, gsize body_len,
 
 static void
 do_single_range (SoupSession *session, SoupMessage *msg,
-		 int start, int end, gboolean succeed)
+		 int start, int end)
 {
 	const char *content_type;
 
@@ -87,31 +85,11 @@ do_single_range (SoupSession *session, SoupMessage *msg,
 
 	soup_session_send_message (session, msg);
 
-	if (succeed) {
-		if (msg->status_code != SOUP_STATUS_PARTIAL_CONTENT) {
-			debug_printf (1, "    Unexpected status %d %s\n",
-				      msg->status_code, msg->reason_phrase);
-			g_object_unref (msg);
-			errors++;
-			return;
-		}
-	} else {
-		if (msg->status_code == SOUP_STATUS_REQUESTED_RANGE_NOT_SATISFIABLE) {
-			debug_printf (1, "    Got expected %d %s\n",
-				      msg->status_code, msg->reason_phrase);
-		} else {
-			const char *content_range;
-
-			debug_printf (1, "    Unexpected status %d %s\n",
-				      msg->status_code, msg->reason_phrase);
-			content_range = soup_message_headers_get_one (msg->response_headers,
-								      "Content-Range");
-			if (content_range)
-				debug_printf (1, "    Content-Range: %s\n", content_range);
-			errors++;
-		}
-
+	if (msg->status_code != SOUP_STATUS_PARTIAL_CONTENT) {
+		debug_printf (1, "    Unexpected status %d %s\n",
+			      msg->status_code, msg->reason_phrase);
 		g_object_unref (msg);
+		errors++;
 		return;
 	}
 
@@ -131,13 +109,13 @@ do_single_range (SoupSession *session, SoupMessage *msg,
 
 static void
 request_single_range (SoupSession *session, const char *uri,
-		      int start, int end, gboolean succeed)
+		      int start, int end)
 {
 	SoupMessage *msg;
 
 	msg = soup_message_new ("GET", uri);
 	soup_message_headers_set_range (msg->request_headers, start, end);
-	do_single_range (session, msg, start, end, succeed);
+	do_single_range (session, msg, start, end);
 }
 
 static void
@@ -218,8 +196,7 @@ request_double_range (SoupSession *session, const char *uri,
 	if (expected_return_ranges == 1) {
 		do_single_range (session, msg,
 				 MIN (first_start, second_start),
-				 MAX (first_end, second_end),
-				 TRUE);
+				 MAX (first_end, second_end));
 	} else
 		do_multi_range (session, msg, expected_return_ranges);
 }
@@ -246,33 +223,11 @@ request_triple_range (SoupSession *session, const char *uri,
 	if (expected_return_ranges == 1) {
 		do_single_range (session, msg,
 				 MIN (first_start, MIN (second_start, third_start)),
-				 MAX (first_end, MAX (second_end, third_end)),
-				 TRUE);
+				 MAX (first_end, MAX (second_end, third_end)));
 	} else
 		do_multi_range (session, msg, expected_return_ranges);
 }
 
-static void
-request_semi_invalid_range (SoupSession *session, const char *uri,
-			    int first_good_start, int first_good_end,
-			    int bad_start, int bad_end,
-			    int second_good_start, int second_good_end)
-{
-	SoupMessage *msg;
-	SoupRange ranges[3];
-
-	msg = soup_message_new ("GET", uri);
-	ranges[0].start = first_good_start;
-	ranges[0].end = first_good_end;
-	ranges[1].start = bad_start;
-	ranges[1].end = bad_end;
-	ranges[2].start = second_good_start;
-	ranges[2].end = second_good_end;
-	soup_message_headers_set_ranges (msg->request_headers, ranges, 3);
-
-	do_multi_range (session, msg, 2);
-}
-
 static void
 do_range_test (SoupSession *session, const char *uri,
 	       gboolean expect_coalesce, gboolean expect_partial_coalesce)
@@ -301,8 +256,7 @@ do_range_test (SoupSession *session, const char *uri,
 	/* A: 0, simple request */
 	debug_printf (1, "Requesting %d-%d\n", 0 * twelfths, 1 * twelfths);
 	request_single_range (session, uri,
-			      0 * twelfths, 1 * twelfths,
-			      TRUE);
+			      0 * twelfths, 1 * twelfths);
 
 	/* B: 11, end-relative request. These two are mostly redundant
 	 * in terms of data coverage, but they may still catch
@@ -310,12 +264,10 @@ do_range_test (SoupSession *session, const char *uri,
 	 */
 	debug_printf (1, "Requesting %d-\n", 11 * twelfths);
 	request_single_range (session, uri,
-			      11 * twelfths, -1,
-			      TRUE);
+			      11 * twelfths, -1);
 	debug_printf (1, "Requesting -%d\n", 1 * twelfths);
 	request_single_range (session, uri,
-			      -1 * twelfths, -1,
-			      TRUE);
+			      -1 * twelfths, -1);
 
 	/* C: 2 and 5 */
 	debug_printf (1, "Requesting %d-%d,%d-%d\n",
@@ -364,21 +316,6 @@ do_range_test (SoupSession *session, const char *uri,
 		debug_printf (1, "\nfull_response and test_response don't match\n");
 		errors++;
 	}
-
-	debug_printf (1, "Requesting (invalid) %d-%d\n",
-		      (int) full_response->length + 1,
-		      (int) full_response->length + 100);
-	request_single_range (session, uri,
-			      full_response->length + 1, full_response->length + 100,
-			      FALSE);
-
-	debug_printf (1, "Requesting (semi-invalid) 1-10,%d-%d,20-30\n",
-		      (int) full_response->length + 1,
-		      (int) full_response->length + 100);
-	request_semi_invalid_range (session, uri,
-				    1, 10,
-				    full_response->length + 1, full_response->length + 100,
-				    20, 30); 
 }
 
 static void
@@ -433,13 +370,3 @@ main (int argc, char **argv)
 	test_cleanup ();
 	return errors != 0;
 }
-
-#else /* HAVE_APACHE */
-
-int
-main (int argc, char **argv)
-{
-	return 77; /* SKIP */
-}
-
-#endif
